@@ -4,7 +4,14 @@ class Hooks(object):
     @classmethod
     def execute_after_tests(cls, results):
         for hook in HOOKS['after_tests']:
-            hook().execute(results)
+            try:
+                hook().execute(results)
+            except Exception, e:
+                raise HookError(e)
+    
+    @classmethod
+    def reset(cls):
+        HOOKS['after_tests'] = []
 
 class MetaHookBase(type):
     def __init__(cls, name, bases, attrs):
@@ -19,4 +26,14 @@ class MetaHookBase(type):
         super(MetaHookBase, cls).__init__(name, bases, attrs)
 
 class AfterTestsHook(object):
-    __metaclass__ = MetaHookBase
\ No newline at end of file
+    __metaclass__ = MetaHookBase
+
+class HookError(Exception):
+    def __init__(self, origin):
+        self.origin = origin
+
+    def __str__(self):
+        return unicode(self)
+    
+    def __unicode__(self):
+        return "HookError: %s" % (self.origin)
